| Title: | Automated Functional Annotation of Genetic Variants and Linked Proxies |
|---|---|
| Description: | To automated functional annotation of genetic variants and linked proxies. Linked SNPs in moderate to high linkage disequilibrium (e.g. r2>0.50) with the corresponding index SNPs will be selected for further analysis. |
| Authors: | Alireza Ani [aut, cre], Zoha Kamali [aut], Ahmad Vaez [aut] |
| Maintainer: | Alireza Ani <[email protected]> |
| License: | GPL-3 |
| Version: | 1.4.6 |
| Built: | 2026-05-09 08:20:46 UTC |
| Source: | https://github.com/cran/SNPannotator |
This function should not be used outside shiny app A list of variants and parameters are received and their information is checked on various API servers.
annotate_shiny(config.list)annotate_shiny(config.list)
config.list |
List. A list of variants andconfiguration parameters. |
a data table with all variant information is returned.
This function is a demo of the annotation algorithm.
demo_annotation()demo_annotation()
A data table containing the variant information for testing is returned. Report files are also saved in the current working directory.
This function list the name, description and size of the available populations in 1000 Genomes project database. This database will be used for returning variables in high LD with the target SNP.
EnsemblDatabases(build = 38)EnsemblDatabases(build = 38)
build |
Genome build. Either 37 or 38. default: 38 |
A data table is returned which includes the name, description and size of the available populations in 1000 Genomes project database.
Shows the data releases available on this REST server. May return more than one release (infrequent non-standard Ensembl configuration).
EnsemblReleases(build = 38)EnsemblReleases(build = 38)
build |
Genome build. Either 37 or 38. default: 38 |
a message is displayed to the user
CHR_POS_REF_ALT.
If an rsID is provided, the function returns the corresponding
genomic positions in both GRCh37 and GRCh38 builds.
When searching for an rsID based on genomic position, the position
parameter should be specified according to the GRCh38 reference genome.Query GTEx portal for Variant's genomic position based on rsID
Retrieves variant information from the GTEx portal using either
an rsID or a variant ID formatted as CHR_POS_REF_ALT.
If an rsID is provided, the function returns the corresponding
genomic positions in both GRCh37 and GRCh38 builds.
When searching for an rsID based on genomic position, the position
parameter should be specified according to the GRCh38 reference genome.
findGenomicPos(id, type = "rsid", file_path = NULL)findGenomicPos(id, type = "rsid", file_path = NULL)
id |
Character string representing the rsID (e.g., |
type |
Character string specifying the type of query. Must be either |
file_path |
character, path to a file for saving results as Excell spreadsheet. |
A data.table containing variant information including:
rsid: variant id in rsID format
chromosome: chromosome number
position_b37: genomic position
position_b38: genomic position
ref: reference allele
alt: alternate allele
This function returns a data frame of LD values between the given variants in a selected population.
findPairwiseLD( rsList, file = NULL, pairwise = FALSE, build = 38, db = "1000GENOMES:phase_3:EUR", r2 = 0.1 )findPairwiseLD( rsList, file = NULL, pairwise = FALSE, build = 38, db = "1000GENOMES:phase_3:EUR", r2 = 0.1 )
rsList |
A vector of rs numbers. |
file |
Path to the Excel file for saving search results. |
pairwise |
If TRUE, compute pairwise LD between all elements of a list. If FALSE, computes the LD between first and other elements of the list. default: FALSE |
build |
Genome build. Either 37 or 38. default: 38 |
db |
The population database for calculating LD scores.
This can be found using |
r2 |
Only return pairs of variants whose r-squared value is equal to or greater than the value provided. default: 0.1. |
A data table with variant information.
This function returns a list of variables that are in high LD with a list of selected variants using data from the Ensembl website.
findProxy( rslist, file = NULL, build = "38", db = "1000GENOMES:phase_3:EUR", window_size = 500, r2 = 0.8 )findProxy( rslist, file = NULL, build = "38", db = "1000GENOMES:phase_3:EUR", window_size = 500, r2 = 0.8 )
rslist |
A vector of rs numbers. |
file |
Path to the Excel file for saving search results. |
build |
Genome build. Either 37 or 38. default: 38 |
db |
The population database for calculating LD scores.
This can be found using |
window_size |
Number of base pairs around the variant for checking LD scores (max = 500kb). default: 500 |
r2 |
The minimum LD threshold for selecting variants around the target SNP. default: 0.8. |
A data table with variant information.
This function retrieves variant information from Ensembl based on the specified genomic position. It takes the chromosome number, start position, and end position as input parameters and searches for variants within this window, using the specified genomic build. If only the start position is provided, the function automatically sets the end position equal to the start position. This is particularly relevant for SNP variants, where the start and end positions are the same. The function returns all variants found within the defined window.
findRSID( chromosome, start_position, end_position = NULL, build = "38", file_path = NULL )findRSID( chromosome, start_position, end_position = NULL, build = "38", file_path = NULL )
chromosome |
Numeric, specifying the chromosome number. |
start_position |
Numeric, specifying the starting base pair position. |
end_position |
Numeric, specifying the ending base pair position. |
build |
Numeric, specifying the genomic build, default value is 38. |
file_path |
character, path to a file for saving results as Excell spreadsheet. |
A data.table containing variant information including:
id: variant id in rsID format
alleles: variant alleles
seq_region_name: chromosome number
start: starting base pair
end: ending base pair
This function provides a sample configuration file. The user can modify the parameters as desired
getConfigFile(dir.path)getConfigFile(dir.path)
dir.path |
The existing folder for copying the file. |
This function merges multiple result files into one.
mergeResultFiles(..., fileName)mergeResultFiles(..., fileName)
... |
list of input files to be merged. |
fileName |
name of the output file. |
A data table is returned.
This function test whether the Ensembl server is accessible or not
pingEnsembl(server)pingEnsembl(server)
server |
name of the server. "https://rest.ensembl.org" can be used for GRCh38 and "https://grch37.rest.ensembl.org" for GRCh37. |
a message is displayed to the user
This function receives the path to the configuration file. A list of variants is received and their information is checked on various API servers.
run_annotation(configurationFilePath, verbose = TRUE)run_annotation(configurationFilePath, verbose = TRUE)
configurationFilePath |
Character. The path to the configuration file. |
verbose |
Logical. Whether to display messages in the console. |
A data table containing all variant information is returned based on the user's selected specifications and parameters. Report files in various formats, including text, HTML, Excel, and image, are saved in the output folder.
This function takes a vector of gene symbols, retrieves their interaction partners from STRING DB, and performs functional enrichment analysis.
run_stringdb_annotation(name, gene_list, required_score = 700, limit = 0, ...)run_stringdb_annotation(name, gene_list, required_score = 700, limit = 0, ...)
name |
A character string specifying a unique identifier for this analysis run. |
gene_list |
A character vector of gene symbols (e.g., HGNC symbols or Ensembl gene IDs). |
required_score |
Threshold of significance to include an interaction, a number between 0 and 1000. |
limit |
Limits the number of interaction partners retrieved per protein, a number between 0 and 100. |
... |
Additional arguments passed to downstream functions for extended customization. |
set of report files, including images, text and excel files containing functional enrichment analysis results.